@@ -1,7 +1,6 @@
 import io
 import copy
 import pandas as pd
-from dataverk.utils.file_functions import url_encode
 
 from dataverk.utils import file_functions
 from dataverk.resources.base_resource import BaseResource
@@ -24,10 +23,11 @@ class DataFrameResource(BaseResource):
         self._schema = self._get_schema()
 
     def formatted_resource_name(self):
-        return url_encode(self._resource_name)
+        return file_functions.remove_whitespace(self._resource_name)
 
     def _resource_path(self):
         return self._create_resource_path(
+            self._datapackage_path,
             self.formatted_resource_name(),
             self._fmt,
             self._compress,
@@ -36,7 +36,7 @@ class DataFrameResource(BaseResource):
     def _get_schema(self):
         fields = []
 
-        for name, dtype in zip(self._resource_data.columns, self._resource_data.dtypes):
+        for name, dtype in zip(self._resource.columns, self._resource.dtypes):
             if str(dtype) == "object":
                 dtype = "string"
             else:
@@ -66,26 +66,26 @@ class DataFrameResource(BaseResource):
             "spec": self._spec,
         }
 
-    def add_to_datapackage(self, dp) -> str:
+    def add_to_datapackage(self, dp) -> None:
         """ Converts a pandas Dataframe object to csv and adds it to the datapackage
 
         :param dp: Datapackage object to append resources to
-        :return: path: str: Path to resource
+        :return: None
         """
+        formatted_resource_name = self._schema.get("name")
         dsv_separator = self._schema.get("dsv_separator")
         dp.datapackage_metadata["resources"].append(self._schema)
-        resource = copy.deepcopy(self._schema)
+        dp.resources[formatted_resource_name] = copy.deepcopy(self._schema)
 
         data_buff = io.StringIO()
-        self._resource_data.to_csv(
+        self._resource.to_csv(
             data_buff, sep=dsv_separator, index=False, encoding="utf-8-sig"
         )
 
         if self._compress:
-            resource["data"] = file_functions.compress_content(data_buff)
-            resource["format"] += ".gz"
+            dp.resources[formatted_resource_name][
+                "data"
+            ] = file_functions.compress_content(data_buff)
+            dp.resources[formatted_resource_name]["format"] += ".gz"
         else:
-            resource["data"] = data_buff.getvalue()
-
-        dp.resources.append(resource)
-        return resource.get("path")
+            dp.resources[formatted_resource_name]["data"] = data_buff.getvalue()
